/** @file
 *  @brief ECG Service sample
 */

/*
 * Copyright (c) 2022 3point3 Labs
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <errno.h>
#include <init.h>
#include <stddef.h>
#include <string.h>
#include <zephyr.h>
#include <zephyr/types.h>

#include "bt_uuid.h"
#include "gatt_service_config.h"
#include <bluetooth/bluetooth.h>
#include <bluetooth/conn.h>
#include <bluetooth/gatt.h>
#include <bluetooth/hci.h>
#include <bluetooth/uuid.h>
//#include "thread_sensor_manager.h"
//#include "MAX86178_Main.h"

#define LOG_LEVEL CONFIG_BT_ECG_LOG_LEVEL
 slimiot_gatt_control_t slimiot_gatt_control;
 user_config user_config_msg;

 uint8_t bleRxQueue[20] = { 0 };
#include <logging/log.h>

LOG_MODULE_REGISTER(config_service);


bool config_notif_enabled = false;

static void hts_ccc_cfg_changed(const struct bt_gatt_attr *attr, uint16_t value)
{
  ARG_UNUSED(attr);
  config_notif_enabled = (value == BT_GATT_CCC_NOTIFY);
  LOG_INF("CONFIG notifications %s", config_notif_enabled ? "enabled" : "disabled");
}

static ssize_t read_config(struct bt_conn *conn, const struct bt_gatt_attr *attr,
                           void *buf, uint16_t len, uint16_t offset)
{
  const char *value = attr->user_data;
  ssize_t sizeRecieved = bt_gatt_attr_read(conn, attr, buf, len, offset, value,
                           sizeof(bleRxQueue));

  // ble_data_handler(bleRxQueue, sizeRecieved);

   return sizeRecieved;

}

static int write_config(struct bt_conn *conn, const struct bt_gatt_attr *attr,
                        const void *buf, uint16_t len, uint16_t offset)
{
  user_config *value = attr->user_data;

  if (offset + len > sizeof(bleRxQueue))
  {
    return -EINVAL;
  }
  memcpy(value + offset, buf, len);
  return len;
}

/* Config Service Declaration */
BT_GATT_SERVICE_DEFINE(config_service,
    BT_GATT_PRIMARY_SERVICE(
        BT_UUID_CONFIG_SERVICE),
    BT_GATT_CHARACTERISTIC(
        BT_UUID_CONFIG_CONTROL_POINT,
        BT_GATT_CHRC_WRITE | BT_GATT_CHRC_READ,
                           BT_GATT_PERM_READ | BT_GATT_PERM_WRITE, read_config, write_config, &bleRxQueue));

//static int config_service_init(const struct device *dev) {
//  ARG_UNUSED(dev);
//  user_config_msg.ams_mode = 0;//AMS_MODE_ECG;
//  user_config_msg.hts_mode = HTS_MODE_ON;
//  user_config_msg.imu_mode = IMU_MODE_LP;
//  user_config_msg.pressure_mode = BAROMETER_MODE_ON;
//  return 0;
//}

//uint8_t config_get_mode_ams() {       return user_config_msg.ams_mode; }
//uint8_t config_get_mode_pressure() {  return user_config_msg.pressure_mode; }
//uint8_t config_get_mode_imu() {       return user_config_msg.imu_mode; }
//uint8_t config_get_mode_hts() {       return user_config_msg.hts_mode; }

//SYS_INIT(config_service_init, APPLICATION, CONFIG_APPLICATION_INIT_PRIORITY);