#pragma once

#include "stdint.h"

#define SAMPLING_PERIOD_ECG 5
#define SAMPLING_PERIOD_PPG 200
#define SAMPLING_PERIOD_PPG_RAW 20
#define SAMPLING_PERIOD_GSR 1000
#define SAMPLING_PERIOD_100MS 100
#define SAMPLING_PERIOD_PAUSED 500
#define SAMPLING_PERIOD_0MS 0
#define SAMPLING_PERIOD_TEMPERATURE 1000
#define SAMPLING_PERIOD_IMU 20
#define SAMPLING_PERIOD_BARO 1000
#define SAMPLING_PERIOD_DUMMY_SERVICE 1000
#define ECG_SEND_LEN 10
#define PPG_RAW_SEND_LEN 10
#define DEFAULT_SEND_QUEUE_LEN  1
#define IMU_SEND_LEN 20

typedef struct
{
  uint8_t ams_mode : 2;
  uint8_t baro_mode: 2;
  uint8_t hts_mode : 2;
  uint8_t imu_mode : 2;

} user_config;


typedef union
{
  struct
  {
    struct
    {
      uint8_t bas_mode : 4;
      uint8_t bas_freq : 4;
    } bas_control;
    struct
    {
      uint8_t baro_mode : 4;
      uint8_t baro_freq : 4;
    } baro_control;
    struct
    {
      uint8_t hts_mode : 4;
      uint8_t hts_freq : 4;
    }hts_control;
    struct
    {
      uint8_t imu_mode : 4;
      uint8_t imu_freq : 4;
    }imu_control;
    struct
    {
      uint8_t ams_mode : 4;
      uint8_t ams_freq : 4;
    }ams_control;
    struct{
      uint16_t gp_a : 16;
      uint16_t gp_b : 16;
    }ppg_led_control;
  } control_bits;
  struct gatt_control_reg
  {
    uint8_t bas_control;
    uint8_t baro_control;
    uint8_t hts_control;
    uint8_t imu_control;
    uint8_t ams_control;
    uint32_t ppg_led_control;
  } gatt_control_reg_val;
  uint8_t gatt_control_reg_buffer[sizeof(struct gatt_control_reg)];
} slimiot_gatt_control_t;


extern slimiot_gatt_control_t slimiot_gatt_control;
extern user_config user_config_msg;
//int config_notify();
//uint8_t config_get_mode_ams();
//uint8_t config_get_mode_pressure();
//uint8_t config_get_mode_imu();
//uint8_t config_get_mode_hts();
/** @defgroup DIS_VENDOR_ID_SRC_VALUES Vendor ID Source values  
 * @{
 */
#define BLE_DIS_VENDOR_ID_SRC_BLUETOOTH_SIG   1                 /**< Vendor ID assigned by Bluetooth SIG. */
#define BLE_DIS_VENDOR_ID_SRC_USB_IMPL_FORUM  2                 /**< Vendor ID assigned by USB Implementer's Forum. */
/** @} */

/**@brief System ID parameters */
typedef struct
{
    uint64_t manufacturer_id;                                   /**< Manufacturer ID. Only 5 LSOs shall be used. */
    uint32_t organizationally_unique_id;                        /**< Organizationally unique ID. Only 3 LSOs shall be used. */
} ble_dis_sys_id_t;

/**@brief IEEE 11073-20601 Regulatory Certification Data List Structure */
typedef struct
{
    uint8_t *  p_list;                                          /**< Pointer the byte array containing the encoded opaque structure based on IEEE 11073-20601 specification. */
    uint8_t    list_len;                                        /**< Length of the byte array. */
} ble_dis_reg_cert_data_list_t;

/**@brief PnP ID parameters */
typedef struct
{
    uint8_t  vendor_id_source;                                  /**< Vendor ID Source. see @ref DIS_VENDOR_ID_SRC_VALUES. */
    uint16_t vendor_id;                                         /**< Vendor ID. */
    uint16_t product_id;                                        /**< Product ID. */
    uint16_t product_version;                                   /**< Product Version. */
} ble_dis_pnp_id_t;


/**@brief GAP connection security modes.
 *
 * Security Mode 0 Level 0: No access permissions at all (this level is not defined by the Bluetooth Core specification).\n
 * Security Mode 1 Level 1: No security is needed (aka open link).\n
 * Security Mode 1 Level 2: Encrypted link required, MITM protection not necessary.\n
 * Security Mode 1 Level 3: MITM protected encrypted link required.\n
 * Security Mode 1 Level 4: LESC MITM protected encrypted link required.\n
 * Security Mode 2 Level 1: Signing or encryption required, MITM protection not necessary.\n
 * Security Mode 2 Level 2: MITM protected signing required, unless link is MITM protected encrypted.\n
 */
typedef struct
{
  uint8_t sm : 4;                     /**< Security Mode (1 or 2), 0 for no permissions at all. */
  uint8_t lv : 4;                     /**< Level (1, 2, 3 or 4), 0 for no permissions at all. */

} ble_gap_conn_sec_mode_t;

/**@brief UTF-8 string data type.
 *
 * @note The type can only hold a pointer to the string data (i.e. not the actual data).
 */
typedef struct
{
    uint16_t  length;                                   /**< String length. */
    uint8_t * p_str;                                    /**< String data. */
} ble_srv_utf8_str_t;


/**@brief Security settings structure.
 * @details This structure contains the security options needed during initialization of the
 *          service.
 */
typedef struct
{
    ble_gap_conn_sec_mode_t read_perm;                  /**< Read permissions. */
    ble_gap_conn_sec_mode_t write_perm;                 /**< Write permissions. */
} ble_srv_security_mode_t;

/**@brief Device Information Service init structure. This contains all possible characteristics 
 *        needed for initialization of the service.
 */
typedef struct
{
    ble_srv_utf8_str_t             manufact_name_str;           /**< Manufacturer Name String. */
    ble_srv_utf8_str_t             model_num_str;               /**< Model Number String. */
    ble_srv_utf8_str_t             serial_num_str;              /**< Serial Number String. */
    ble_srv_utf8_str_t             hw_rev_str;                  /**< Hardware Revision String. */
    ble_srv_utf8_str_t             fw_rev_str;                  /**< Firmware Revision String. */
    ble_srv_utf8_str_t             sw_rev_str;                  /**< Software Revision String. */
    ble_dis_sys_id_t *             p_sys_id;                    /**< System ID. */
    ble_dis_reg_cert_data_list_t * p_reg_cert_data_list;        /**< IEEE 11073-20601 Regulatory Certification Data List. */
    ble_dis_pnp_id_t *             p_pnp_id;                    /**< PnP ID. */
    ble_srv_security_mode_t        dis_attr_md;                 /**< Initial Security Setting for Device Information Characteristics. */
} ble_dis_init_t;